@@ -1,11 +1,8 @@
 class ServiceEnum:
-    AD_GROUP_QUALITY = 'adgroup_quality'
     ADMIN_TOOLS = 'admin_tools'
     ATTRIBUTION_MODELS = 'attribution_models'
-    BID_OPTIMISATION = 'bid_optimisation'
     CLIENTS = 'clients'
     DATALAB = 'datalab_monitoring'
-    DEVICE_OPTIMISATION = 'device_optimisation'
     FEED_DRIVEN_ADS = 'feed_driven_ads'
     LAB = 'lab'
     NOTIFICATIONS = 'notification'
